#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MINMAG_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MINMAG_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/minmag.hpp>

#endif
